@@ -4,6 +4,11 @@ from inspect import iscoroutinefunction
 from typing import Any
 
 from insanic.commands import Command, ArgumentParser
+from insanic.commands.migrations import (
+    MigrationsApplyCommand,
+    MigrationsGenerateCommand,
+    MigrationsListCommand,
+)
 from insanic.commands.routes import RoutesCommand
 from insanic.commands.server import ServerCommand
 from insanic.utils import application_context, run_async
@@ -12,6 +17,10 @@ def load_commands() -> dict[str, Command]:
     return {
         'routes': RoutesCommand(),
         'server': ServerCommand(),
+
+        'migrations:apply': MigrationsApplyCommand(),
+        'migrations:generate': MigrationsGenerateCommand(),
+        'migrations:list': MigrationsListCommand(),
     }
 
 async def execute_async_command(command: Command, *args: Any, **kwargs: Any) -> None:
