@@ -4,6 +4,7 @@ from sanic import Sanic
 from tortoise import Tortoise, Model, fields, functions, queryset
 from tortoise.backends.base.client import BaseDBAsyncClient
 from tortoise.manager import Manager as ModelManager
+from tortoise.transactions import in_transaction
 
 
 __all__ = (
@@ -12,6 +13,7 @@ __all__ = (
     'fields',
     'functions',
     'queryset',
+    'in_transaction',
     'init_db_connection',
     'close_db_connection',
 )
