@@ -4,7 +4,7 @@ import importlib
 from collections.abc import AsyncGenerator, Coroutine, Generator
 from contextlib import asynccontextmanager
 from pathlib import Path
-from typing import Any
+from typing import Any, Awaitable, Callable
 
 from insanic.app import Application
 
@@ -17,6 +17,8 @@ class Container:
     FIELD_BASE_CLASS = ContainerField
     RESERVED_ATTRS: list[str] = []
 
+    _field_names: list[str] = []
+
     def __init__(self, *args: Any, **kwargs: Any) -> None: # pylint: disable=unused-argument
         # List of declared fields
         self._field_names = [
@@ -50,6 +52,12 @@ def read_file_content(file_path: str | Path) -> str:
 def run_async(coroutine: Coroutine) -> Any:
     return asyncio.run(coroutine)
 
+async def ensure_run(result: Awaitable | Callable) -> Any:
+    if isawaitable(result):
+        return await result
+
+    return result
+
 def load_application() -> Application:
     app_module = importlib.import_module('app', package='src')  # importing src/app.py
     application: Application = getattr(app_module, 'application')
